@@ -9,11 +9,11 @@
 #define QT_FEATURE_wayland_client_xdg_shell_v5 1
 #define QT_FEATURE_wayland_client_xdg_shell_v6 1
 #define QT_FEATURE_wayland_datadevice 1
-#define QT_FEATURE_wayland_dmabuf_server_buffer 1
-#define QT_FEATURE_wayland_drm_egl_server_buffer 1
+#define QT_FEATURE_wayland_dmabuf_server_buffer -1
+#define QT_FEATURE_wayland_drm_egl_server_buffer -1
 #define QT_FEATURE_wayland_egl 1
 #define QT_FEATURE_wayland_libhybris_egl_server_buffer -1
-#define QT_FEATURE_wayland_shm_emulation_server_buffer 1
+#define QT_FEATURE_wayland_shm_emulation_server_buffer -1
 #define QT_FEATURE_wayland_vulkan_server_buffer 1
 #define QT_FEATURE_xcomposite_egl -1
 #define QT_FEATURE_xcomposite_glx -1
